@@ -50,7 +50,7 @@ Usage:
       [-cuts cuts.txt] \\
       [-polymer-directions polarities.txt \\
       [-dir-indices ia ib] \\
-      [-box paddingX,paddingY,paddingZ] \\
+      [-padding paddingX,paddingY,paddingZ] \\
       < coords.raw > polymer.lt
 
 """
@@ -126,13 +126,13 @@ class GPSettings(object):
                 (argv[i].lower() == '-i')):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a file name.\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a file name.\n')
                 self.infile_name = argv[i + 1]
                 del(argv[i:i + 2])
             elif argv[i].lower() == '-bond':
                 if i + 3 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by 3 strings.\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by 3 strings.\n')
                 # self.bonds_name.append(argv[i+1])
                 self.bonds_type.append(argv[i + 1])
                 self.bonds_atoms.append((argv[i + 2],
@@ -142,7 +142,7 @@ class GPSettings(object):
             elif argv[i].lower() == '-angle':
                 if i + 7 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by 4 strings and 3 integers.\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by 4 strings and 3 integers.\n')
                 # self.angles_name.append(argv[i+1])
                 self.angles_type.append(argv[i + 1])
                 self.angles_atoms.append((argv[i + 2],
@@ -160,7 +160,7 @@ class GPSettings(object):
             elif argv[i].lower() == '-dihedral':
                 if i + 9 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by 5 strings and 4 integers.\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by 5 strings and 4 integers.\n')
                 # self.dihedrals_name.append(argv[i+1])
                 self.dihedrals_type.append(argv[i + 1])
                 self.dihedrals_atoms.append((argv[i + 2],
@@ -181,7 +181,7 @@ class GPSettings(object):
             elif argv[i].lower() == '-improper':
                 if i + 9 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by 5 strings and 4 integers.\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by 5 strings and 4 integers.\n')
                 # self.impropers_name.append(argv[i+1])
                 self.impropers_type.append(argv[i + 1])
                 self.impropers_atoms.append((argv[i + 2],
@@ -202,25 +202,25 @@ class GPSettings(object):
             elif (argv[i].lower() == '-monomer-name'):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a string\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a string\n')
                 self.name_monomer = argv[i + 1]
                 del(argv[i:i + 2])
             elif (argv[i].lower() == '-sequence'):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a file name\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a file name\n')
                 self.name_sequence_file = argv[i + 1]
                 del(argv[i:i + 2])
 
             elif (argv[i].lower() == '-cuts'):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a file name\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a file name\n')
                 try:
                     f = open(argv[i + 1], "r")
                 except IOError:
                     raise InputError(
-                        'Error: file ' + argv[i + 1] + ' could not be opened for reading\n')
+                        'Error: File "' + argv[i + 1] + '" could not be opened for reading\n')
                 for line_orig in f:
                     line = line_orig.strip()
                     ic = line.find('#')
@@ -238,12 +238,12 @@ class GPSettings(object):
             elif (argv[i].lower() == '-polymer-directions'):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a file name\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a file name\n')
                 try:
                     f = open(argv[i + 1], "r")
                 except IOError:
                     raise InputError(
-                        'Error: file ' + argv[i + 1] + ' could not be opened for reading\n')
+                        'Error: File "' + argv[i + 1] + '" could not be opened for reading\n')
                 for line_orig in f:
                     line = line_orig.strip()
                     ic = line.find('#')
@@ -268,13 +268,13 @@ class GPSettings(object):
             elif (argv[i].lower() == '-polymer-name'):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a string\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a string\n')
                 self.name_polymer = argv[i + 1]
                 del(argv[i:i + 2])
             elif (argv[i].lower() == '-inherits'):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a string\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a string\n')
                 self.inherits = argv[i + 1]
                 if self.inherits.find('inherits ') == 0:
                     self.inherits = ' ' + self.inherits
@@ -286,20 +286,20 @@ class GPSettings(object):
             elif (argv[i].lower() == '-header'):
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a string (usually in quotes)\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a string (usually in quotes)\n')
                 if self.header != '':
                     self.header += '\n'
                 self.header += argv[i + 1]
                 del(argv[i:i + 2])
             elif argv[i].lower() == '-axis':
                 if i + 1 >= len(argv):
-                    raise InputError('Error: ' + argv[i] + ' flag should be followed ' +
+                    raise InputError('Error: The ' + argv[i] + ' flag should be followed ' +
                                      'by 3 numbers separated by commas (no spaces)\n')
                 self.direction_orig = list(map(float, argv[i + 1].split(',')))
                 del(argv[i:i + 2])
             elif argv[i].lower() == '-circular':
                 if i + 1 >= len(argv):
-                    raise InputError('Error: ' + argv[i] + ' flag should be followed by an argument\n' +
+                    raise InputError('Error: The ' + argv[i] + ' flag should be followed by an argument\n' +
                                      '       ("yes", "no", or "connected")\n')
                 if argv[i + 1].lower() == 'yes':
                     self.connect_ends = True
@@ -311,31 +311,32 @@ class GPSettings(object):
                     self.connect_ends = False
                     self.is_circular = False
                 else:
-                    raise InputError('Error: ' + argv[i] + ' flag should be followed by an argument\n' +
+                    raise InputError('Error: The ' + argv[i] + ' flag should be followed by an argument\n' +
                                      '       ("yes", "no", or "connected")\n')
                 del(argv[i:i + 2])
             elif argv[i].lower() == '-helix':
                 if i + 1 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by a number (angle in degrees)\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by a number (angle in degrees)\n')
                 self.delta_phi = float(argv[i + 1])
                 del(argv[i:i + 2])
             elif (argv[i].lower() == '-dir-indices'):
                 if i + 2 >= len(argv):
                     raise InputError(
-                        'Error: ' + argv[i] + ' flag should be followed by two integers\n')
+                        'Error: The ' + argv[i] + ' flag should be followed by two integers\n')
                 self.dir_index_offsets = (int(argv[i + 1]), int(argv[i + 2]))
                 if self.dir_index_offsets[0] == self.dir_index_offsets[1]:
                     raise InputError(
                         'Error: The two numbers following ' + argv[i] + ' must not be equal.\n')
                 del(argv[i:i + 3])
-            elif (argv[i].lower() == '-box'):
+            elif ((argv[i].lower() == '-padding') or
+                  (argv[i].lower() == '-box')):
                 if i + 1 >= len(argv):
-                    raise InputError('Error: ' + argv[i] + ' flag should be followed ' +
+                    raise InputError('Error: The ' + argv[i] + ' flag should be followed\n' +
                                      'by 3 numbers separated by commas (no spaces)\n')
                 self.box_padding = list(map(float, argv[i + 1].split(',')))
                 if len(self.box_padding) == 1:
-                    self.box_padding = self.box_padding * 3
+                    self.box_padding = [self.box_padding] * 3
                 del(argv[i:i + 2])
             elif (argv[i].lower() in ('-orientations','-orientations')):
                 self.orientations_file = argv[i+1]
@@ -367,24 +368,24 @@ class GPSettings(object):
 
         for b in range(0, len(self.bonds_type)):
             if len(self.bonds_type) > 1:
-                self.bonds_name.append('genpoly' + str(b + 1) + '_')
+                self.bonds_name.append('genp_bond' + str(b + 1) + '_')
             else:
-                self.bonds_name.append('genpoly')
+                self.bonds_name.append('genp_bond_')
         for b in range(0, len(self.angles_type)):
             if len(self.angles_type) > 1:
-                self.angles_name.append('genpoly' + str(b + 1) + '_')
+                self.angles_name.append('genp_angle' + str(b + 1) + '_')
             else:
-                self.angles_name.append('genpoly')
+                self.angles_name.append('genp_angle_')
         for b in range(0, len(self.dihedrals_type)):
             if len(self.dihedrals_type) > 1:
-                self.dihedrals_name.append('genpoly' + str(b + 1) + '_')
+                self.dihedrals_name.append('genp_dihedral' + str(b + 1) + '_')
             else:
-                self.dihedrals_name.append('genpoly')
+                self.dihedrals_name.append('genp_dihedral_')
         for b in range(0, len(self.impropers_type)):
             if len(self.impropers_type) > 1:
-                self.impropers_name.append('genpoly' + str(b + 1) + '_')
+                self.impropers_name.append('genp_improper' + str(b + 1) + '_')
             else:
-                self.impropers_name.append('genpoly')
+                self.impropers_name.append('genp_improper_')
 
 
 
@@ -427,8 +428,8 @@ class GenPoly(object):
         self.coords_multi = []  # a list-of-list-of-lists of numbers Nxnx3
         self.name_sequence_multi = []
         self.direction_vects = []
-        self.box_bounds_min = [0.0, 0.0, 0.0]
-        self.box_bounds_max = [0.0, 0.0, 0.0]
+        self.box_bounds_min = None
+        self.box_bounds_max = None
         self.N = 0
         self.orientations_multi = []
         self.helix_angles_multi = []
@@ -585,9 +586,9 @@ class GenPoly(object):
         else:
             for i in range(1, N - 1):
                 for d in range(0, 3):
-                    self.direction_vects[i][d] = coords[
-                        i + self.settings.dir_index_offsets[1]][d] - coords[
-                            i + self.settings.dir_index_offsets[0]][d]
+                    self.direction_vects[i][d] = (coords[i + self.settings.dir_index_offsets[1]][d]
+                                                  -
+                                                  coords[i + self.settings.dir_index_offsets[0]][d])
 
             for d in range(0, 3):
                 self.direction_vects[0][d] = coords[1][d] - coords[0][d]
@@ -783,10 +784,12 @@ class GenPoly(object):
                len(self.settings.bonds_type) ==
                len(self.settings.bonds_atoms) ==
                len(self.settings.bonds_index_offsets))
+
         if len(self.settings.bonds_type) > 0:
             outfile.write("\n"
                           "\n"
                           "write(\"Data Bonds\") {\n")
+
         WrapPeriodic.bounds_err = False
         for i in range(0, N):
             test = False
@@ -801,13 +804,12 @@ class GenPoly(object):
                         continue
                 outfile.write(
                     "  $bond:" + self.settings.bonds_name[b] + str(i + 1))
-                if len(self.settings.bonds_type) > 1:
-                    outfile.write("_" + str(b + 1))
                 outfile.write(" @bond:" + self.settings.bonds_type[b] + " $atom:mon[" + str(I) + "]/" + self.settings.bonds_atoms[
                               b][0] + " $atom:mon[" + str(J) + "]/" + self.settings.bonds_atoms[b][1] + "\n")
         if len(self.settings.bonds_type) > 0:
             outfile.write("}  # write(\"Data Bonds\") {...\n\n\n")
 
+
         assert(len(self.settings.angles_name) ==
                len(self.settings.angles_type) ==
                len(self.settings.angles_atoms) ==
@@ -830,8 +832,6 @@ class GenPoly(object):
                         continue
                 outfile.write(
                     "  $angle:" + self.settings.angles_name[b] + str(i + 1))
-                if len(self.settings.angles_type) > 1:
-                    outfile.write("_" + str(b + 1))
                 outfile.write(" @angle:" + self.settings.angles_type[b] +
                               " $atom:mon[" + str(I) + "]/" + self.settings.angles_atoms[b][0] +
                               " $atom:mon[" + str(J) + "]/" + self.settings.angles_atoms[b][1] +
@@ -840,6 +840,7 @@ class GenPoly(object):
         if len(self.settings.angles_type) > 0:
             outfile.write("}  # write(\"Data Angles\") {...\n\n\n")
 
+
         assert(len(self.settings.dihedrals_name) ==
                len(self.settings.dihedrals_type) ==
                len(self.settings.dihedrals_atoms) ==
@@ -864,8 +865,6 @@ class GenPoly(object):
                         continue
                 outfile.write("  $dihedral:" +
                               self.settings.dihedrals_name[b] + str(i + 1))
-                if len(self.settings.dihedrals_type) > 1:
-                    outfile.write("_" + str(b + 1))
                 outfile.write(" @dihedral:" + self.settings.dihedrals_type[b] +
                               " $atom:mon[" + str(I) + "]/" + self.settings.dihedrals_atoms[b][0] +
                               " $atom:mon[" + str(J) + "]/" + self.settings.dihedrals_atoms[b][1] +
@@ -875,6 +874,7 @@ class GenPoly(object):
         if len(self.settings.dihedrals_type) > 0:
             outfile.write("}  # write(\"Data Dihedrals\") {...\n\n\n")
 
+
         assert(len(self.settings.impropers_name) ==
                len(self.settings.impropers_type) ==
                len(self.settings.impropers_atoms) ==
@@ -899,8 +899,6 @@ class GenPoly(object):
                         continue
                 outfile.write("  $improper:" +
                               self.settings.impropers_name[b] + str(i + 1))
-                if len(self.settings.impropers_type) > 1:
-                    outfile.write("_" + str(b + 1))
                 outfile.write(" @improper:" + self.settings.impropers_type[b] +
                               " $atom:mon[" + str(I) + "]/" + self.settings.impropers_atoms[b][0] +
                               " $atom:mon[" + str(J) + "]/" + self.settings.impropers_atoms[b][1] +
@@ -949,8 +947,8 @@ class GenPoly(object):
 def main():
     try:
         g_program_name = __file__.split('/')[-1]
-        g_version_str = '0.1.0'
-        g_date_str = '2019-12-13'
+        g_version_str = '0.1.1'
+        g_date_str = '2020-4-11'
         sys.stderr.write(g_program_name + ' v' +
                          g_version_str + ' ' + g_date_str + '\n')
         argv = [arg for arg in sys.argv]
